@@ -1,18 +1,16 @@
 """URLs for the ``event_rsvp`` app."""
 from django.conf.urls.defaults import patterns, url
-from django.views.generic import ListView
 
-from .models import Enquiry
-from .views import EnquirySubmitView
+from . import views
 
 
 urlpatterns = patterns(
     '',
     url(r'^(?P<pk>\d+)/$',
-        EnquirySubmitView.as_view(),
+        views.EnquirySubmitView.as_view(),
         name='enquiry_detail'),
 
     url(r'^$',
-        ListView.as_view(model=Enquiry),
+        views.EnquiryListView.as_view(),
         name='enquiry_list'),
 )
